@@ -82,13 +82,13 @@ def SilicateLayers(Planet, Params):
             Mdiff_frac = 1 - Mtot_kg / Planet.Bulk.M_kg
             MdiffThresh = 0.05
             if np.min(Mdiff_frac) > MdiffThresh:
-                raise RuntimeError(f'All masses for some SilicateLayers solutions are more than {100*MdiffThresh:d}% ' +
+                raise RuntimeError(f'All masses for some SilicateLayers solutions are more than {100*MdiffThresh:g}% ' +
                                    'less than the total body mass. This likely means the ice shell is too thick to be ' +
                                    'consistent with the value of Steps.iSilStart -- try to increase Bulk.Tb_K or ' +
                                    'decrease Steps.iSilStart.')
             else:
-                log.warning(f'All masses for some SilicateLayers solutions are more than {100*MdiffThresh:d}% less ' +
-                            f'than the total body mass, though the closest is only {100*np.min(Mdiff_frac):d}% less.')
+                log.warning(f'All masses for some SilicateLayers solutions are more than {100*MdiffThresh:g}% less ' +
+                            f'than the total body mass, though the closest is only {100*np.min(Mdiff_frac):g}% less.')
         else:
             # Record the first entry in the list of models with a total mass lower than the bulk mass --
             # this is *the* match for this Htidal coupling
