@@ -1,5 +1,5 @@
 import numpy as np
-import logging as log
+import logging
 from PlanetProfile.Thermodynamics.Geophysical import PropagateConduction, EvalLayerProperties, \
     PorosityCorrectionVacIce, PorosityCorrectionFilledIce, PropagateAdiabaticSolid, \
     PropagateAdiabaticPorousVacIce, PropagateAdiabaticPorousFilledIce
@@ -8,6 +8,9 @@ from PlanetProfile.Thermodynamics.ThermalProfiles.ThermalProfiles import Convect
     kThermIsobaricAnderssonIbari2005, kThermHobbs1974, kThermMelinder2007
 from PlanetProfile.Utilities.defineStructs import Constants
 
+# Assign logger
+log = logging.getLogger('PlanetProfile')
+
 def IceIConvectSolid(Planet, Params):
     """ Apply convection models from literature to determine thermal profile and
         state variables for possibly convecting ice I layers
